package com.goomood.phm.service;

import java.util.List;
import com.goomood.phm.domain.BasicDeviceInfo;

/**
 * 设备信息Service接口
 * 
 * @author goomood
 * @date 2024-11-16
 */
public interface IBasicDeviceInfoService 
{
    /**
     * 查询设备信息
     * 
     * @param id 设备信息主键
     * @return 设备信息
     */
    public BasicDeviceInfo selectBasicDeviceInfoById(Long id);

    /**
     * 查询设备信息列表
     * 
     * @param basicDeviceInfo 设备信息
     * @return 设备信息集合
     */
    public List<BasicDeviceInfo> selectBasicDeviceInfoList(BasicDeviceInfo basicDeviceInfo);

    /**
     * 新增设备信息
     * 
     * @param basicDeviceInfo 设备信息
     * @return 结果
     */
    public int insertBasicDeviceInfo(BasicDeviceInfo basicDeviceInfo);

    /**
     * 修改设备信息
     * 
     * @param basicDeviceInfo 设备信息
     * @return 结果
     */
    public int updateBasicDeviceInfo(BasicDeviceInfo basicDeviceInfo);

    /**
     * 批量删除设备信息
     * 
     * @param ids 需要删除的设备信息主键集合
     * @return 结果
     */
    public int deleteBasicDeviceInfoByIds(Long[] ids);

    /**
     * 删除设备信息信息
     * 
     * @param id 设备信息主键
     * @return 结果
     */
    public int deleteBasicDeviceInfoById(Long id);
}
